#
# spec file for package php5-pear-Auth_SASL
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           php5-pear-Auth_SASL
%define pear_name  Auth_SASL
%define pear_sname auth_sasl
Summary:        Abstraction of various SASL mechanism responses
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Servers
Version:        1.0.6
Release:        12.3
BuildArch:      noarch
Url:            http://pear.php.net/package/%{pear_name}
Source:         http://pear.php.net/get/%{pear_name}-%{version}.tgz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  php >= 4.2.0
%if 0%{?sles_version} == 10
BuildRequires:  php-macros
%else
BuildRequires:  php-devel >= 4.2.0
%endif
BuildRequires:  php-pear >= 1.4.3
Requires:       php >= 4.2.0
Requires:       php-pear >= 1.4.3

Provides:       php-pear-%{pear_name} pear-%{pear_name}
Provides:       php5-pear-%{pear_sname} = %{version}
Provides:       php-pear-%{pear_sname} = %{version}
Provides:       pear-%{pear_sname} = %{version}
Obsoletes:      php5-pear-%{pear_sname} < %{version}
Obsoletes:      php-pear-%{pear_sname} < %{version}
Obsoletes:      pear-%{pear_sname} < %{version}

%description
Provides code to generate responses to common SASL mechanisms,
 including:

  - Digest-MD5
  - CramMD5
  - Plain
  - Anonymous
  - Login (Pseudo mechanism)

%prep
%setup -c

%build

%install
%{__mv} package*.xml %{pear_name}-%{version}
cd %{pear_name}-%{version}
which pear
PHP_PEAR_PHP_BIN="$(which php) -d memory_limit=50m"

%{__pear} -v \
	-d doc_dir=/doc \
	-d bin_dir=%{_bindir} \
	-d data_dir=%{php_peardir}/data \
	install --offline --nodeps -R "%{buildroot}" package.xml

%{__install} -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml

%{__rm} -rf %{buildroot}/{doc,tmp}
%{__rm} -rf %{buildroot}%{php_peardir}/.{filemap,lock,registry,channels,depdb,depdblock}

cd ..

%php_pear_gen_filelist

%post  
# on `rpm -ivh` PARAM is 1
# on `rpm -Uvh` PARAM is 2
if [ "$1" = "1" ]; then
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml
fi 
if [ "$1" = "2" ]; then
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml
fi

%postun  
# on `rpm -e` PARAM is 0
if [ "$1" = "0" ]; then
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name}
fi

%clean
%{__rm} -rf %{buildroot}

%files -f %{name}.files
%defattr(-, root, root)

%changelog
* Fri Feb  1 2013 aj@ajaissle.de
- Improved spec to serve more build targets.
* Tue Nov 27 2012 Ralf Lang <lang@b1-systems.de>
- need to explicitly include php53-devel to supersede php-macros for SLE11 builds
- SLES 11SP2 compatibility
* Mon Nov 26 2012 Ralf Lang <lang@b1-systems.de>
- version 1.0.6
  Bug #18856: Authentication warnings because of wrong Auth_SASL::factory argument [kguest]
  Added basic support for any mechanism of the SCRAM family; with thanks to Jehan Pagès. [kguest]
  crammd5 and digestmd5 mechanisms name deprecated in favour of IANA registered names 'cram-md5' and 'digest-md5'; with thanks to Jehan Pagès. [kguest]
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Mon Jan 31 2011 lang@b1-systems.de
- BSD license as of pear package statement
* Thu Jan 20 2011 chris@computersalat.de
- change to php_pear_gen_filelist macro
* Wed Jan 19 2011 chris@computersalat.de
- pkg rename php5-pear-Auth_SASL
- merge with php-pear-auth_sasl, php5-pear-auth_sasl
- changelog to changes file
- added php-macros
* Tue Dec 21 2010 lang@b1-systems.de
- updated to 1.0.4
  * Fix bug #16624: open_basedir restriction warning in
    DigestMD5.php [till]
- dropped php4 support in package
- cleaned up some warnings
* Tue Nov 10 2009 chris@computersalat.de
- new version 1.0.3
  * Move SVN to proper directory structure [cweiske]
  * Fix Bug #8775: Error in package.xml
  * Fix Bug #14671: Security issue due to seeding random number
    generator [cweiske]
* Sat May 30 2009 chris@computersalat.de
- fixed post script
* Thu May 21 2009 chris@computersalat.de
- added stuff to automatically create correct filelist
  o tested against Factory (1120)
  o opensuse >= 1100 complains about
    "directory not owned by package"
- some rpmlint fixes
* Tue May 19 2009 chris@computersalat.de
- beautify spec
  o new spec header
  o package rename due to package convention
  o removed php4 stuff, deps
  o added Provides and Obsoletes for old package names.
    This should not break deps
- removed 1.0.1 source
* Tue Jun 13 2006 suse-tux@gmx.de
- updated to version 1.0.2
- added rpmmacros (changed "mv" to "%%__mv" etc.)
- removed #usedforbuild, added %%clean-macro
- made spec file portable for older/newer suse_versions
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 mmarek@suse.de
- fix filelist, remove temporary files created by pear installer
- unify php5-pear-*.spec files
- increase php's memory_limit during installation (parsing
  xml needs more than default 8M sometimes)
* Mon Jan 16 2006 mmarek@suse.cz
- created package to satisfy horde dependencies
